@@ -53,16 +53,11 @@
 #include <KWindowSystem>
 #include <KIO/Global>
 
-#if QT_VERSION >= QT_VERSION_CHECK(5,7,0)
 #include "qdbusmenubar_p.h"
-#endif
 
 static const QByteArray s_x11AppMenuServiceNamePropertyName = QByteArrayLiteral("_KDE_NET_WM_APPMENU_SERVICE_NAME");
 static const QByteArray s_x11AppMenuObjectPathPropertyName = QByteArrayLiteral("_KDE_NET_WM_APPMENU_OBJECT_PATH");
 
-static const QByteArray s_waylandAppMenuServiceNamePropertyName = QByteArrayLiteral("KDE_APPMENU_SERVICE_NAME");
-static const QByteArray s_waylandAppMenuObjectPathPropertyName = QByteArrayLiteral("KDE_APPMENU_OBJECT_PATH");
-
 static bool checkDBusGlobalMenuAvailable()
 {
     if (qEnvironmentVariableIsSet("KDE_NO_GLOBAL_MENU")) {
@@ -125,13 +120,6 @@ QIcon KdePlatformTheme::fileIcon(const QFileInfo &fileInfo, QPlatformTheme::Icon
     return QIcon::fromTheme(KIO::iconNameForUrl(QUrl::fromLocalFile(fileInfo.absoluteFilePath())));
 }
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 8, 0)
-QPixmap KdePlatformTheme::fileIconPixmap(const QFileInfo &fileInfo, const QSizeF &size, QPlatformTheme::IconOptions iconOptions) const
-{
-    return fileIcon(fileInfo, iconOptions).pixmap(size.toSize(), QIcon::Normal);
-}
-#endif
-
 const QPalette *KdePlatformTheme::palette(Palette type) const
 {
     QPalette *palette = m_hints->palette(type);
@@ -350,7 +338,6 @@ QPlatformSystemTrayIcon *KdePlatformTheme::createPlatformSystemTrayIcon() const
     return new KDEPlatformSystemTrayIcon;
 }
 
-#if QT_VERSION >= QT_VERSION_CHECK(5,7,0)
 QPlatformMenuBar *KdePlatformTheme::createPlatformMenuBar() const
 {
     if (isDBusGlobalMenuAvailable()) {
@@ -374,13 +361,11 @@ QPlatformMenuBar *KdePlatformTheme::createPlatformMenuBar() const
 
             if (m_kwaylandIntegration) {
                 if (oldWindow) {
-                    m_kwaylandIntegration->setWindowProperty(oldWindow, s_waylandAppMenuServiceNamePropertyName, {});
-                    m_kwaylandIntegration->setWindowProperty(oldWindow, s_waylandAppMenuObjectPathPropertyName, {});
+                    m_kwaylandIntegration->setAppMenu(oldWindow, QString(), QString());
                 }
 
                 if (newWindow) {
-                    m_kwaylandIntegration->setWindowProperty(newWindow, s_waylandAppMenuServiceNamePropertyName, serviceName.toUtf8());
-                    m_kwaylandIntegration->setWindowProperty(newWindow, s_waylandAppMenuObjectPathPropertyName, objectPath.toUtf8());
+                    m_kwaylandIntegration->setAppMenu(newWindow, serviceName, objectPath);
                 }
             }
         });
@@ -390,7 +375,6 @@ QPlatformMenuBar *KdePlatformTheme::createPlatformMenuBar() const
 
     return nullptr;
 }
-#endif
 
 //force QtQuickControls2 to use the desktop theme as default
 void KdePlatformTheme::setQtQuickControlsTheme()
